@@ -59,7 +59,7 @@ import textwrap
 
 from . import __version__
 from . import external_program_calls as ex
-from . pymupdf_routines import has_mupdf, DocumentPages
+from . pymupdf_routines import has_mupdf, MuPdfDocument
 
 if not has_mupdf:
     print("\nError in pdfCropMargins: The GUI feature requires PyMuPDF"
@@ -307,7 +307,7 @@ def create_gui(input_doc_fname, fixed_input_doc_fname, output_doc_fname,
     ## Set up the document and window.
     ##
 
-    document_pages = DocumentPages(args)
+    document_pages = MuPdfDocument(args)
     num_pages = document_pages.open_document(fixed_input_doc_fname)
     curr_page = 0
 
@@ -797,11 +797,11 @@ def create_gui(input_doc_fname, fixed_input_doc_fname, output_doc_fname,
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message="Your title is not a string.")
         window = sg.Window(title=window_title, layout=layout, return_keyboard_events=True,
-                           location=(left_pixels, 0), resizable=True,
-                           no_titlebar=False,
+                           location=(left_pixels, 0), resizable=True, no_titlebar=False,
+                           #use_ttk_buttons=True, ttk_theme=sg.THEME_DEFAULT,
                            use_default_focus=False, alpha_channel=0)
 
-    #window.Layout(layout)
+    #window.Layout(layout) # Old way, now in Window call, delete after testing.
     window.Finalize() # Newer pySimpleGui versions have finalize kwarg in window def.
     wait_indicator_text.Update(visible=False)
 
@@ -953,6 +953,7 @@ def create_gui(input_doc_fname, fixed_input_doc_fname, output_doc_fname,
         image_element.Update(data=data)
 
     window.Close()
+    document_pages.close_document() # Be sure document is closed (bug with -mo without this).
     return did_crop
 
 #
