@@ -39,15 +39,15 @@ try: # Extra dependencies for the GUI version.  Make sure they are installed.
         import fitz
     if not [int(i) for i in fitz.VersionBind.split(".")] >= [1, 16, 17]:
         has_mupdf = False
-        DocumentPages = None
+        MuPdfDocument = None
 
 except ImportError:
     has_mupdf = False
-    DocumentPages = None
+    MuPdfDocument = None
 
 if has_mupdf:
 
-    class DocumentPages:
+    class MuPdfDocument:
         """Holds `pyMuPDF` document and PyMuPDF pages of the document for the GUI
         to display.  Has methods to get rendered images.  Note that the page numbering
         convention is from zero."""
@@ -76,22 +76,25 @@ if has_mupdf:
                       .format(doc_fname), file=sys.stderr)
                 ex.cleanup_and_exit(1)
 
+            if not hasattr(self.document, "is_encrypted"): # TODO: Temporary workaround, PyMuPDF renaming.
+                self.document.is_encrypted = self.document.isEncrypted # Version 1.17 vs. version 1.18.
+
             # Decrypt if necessary.
-            if self.document.isEncrypted:
+            if self.document.is_encrypted:
                 if self.args.password:
                     # Return code is positive for success, negative for failure. If positive,
                     #   bit 0 set = no password required
                     #   bit 1 set = user password authenticated
                     #   bit 2 set = owner password authenticated
                     authenticate_code = self.document.authenticate(self.args.password)
-                    if self.document.isEncrypted:
+                    if self.document.is_encrypted:
                         print("\nError in pdfCropMargins: The document was not correctly "
                               "decrypted by PyMuPDF using the password passed in.",
                               file=sys.stderr)
                         ex.cleanup_and_exit(1)
                 else: # Try an empty password.
                     authenticate_code = self.document.authenticate("")
-                    if self.document.isEncrypted:
+                    if self.document.is_encrypted:
                         print("\nError in pdfCropMargins: The document is encrypted "
                               "and the empty password does not work.  Try passing in a "
                               "password with the '--password' option.",
